@@ -1,7 +1,8 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -100,7 +101,15 @@ on_menu_exit_activate (GtkMenuItem * menuitem, gpointer user_data)
 	if (logchanged)
 		create_savedialog ();
 	else
-		create_exitdialog ();
+	{
+		if (preferences.areyousure > 0)
+			create_exitdialog ();
+		else
+		{
+			save_windowsize_and_cleanup ();
+			gtk_main_quit ();
+		}
+	}
 }
 
 /* save current page to the log */
