@@ -170,6 +170,8 @@ cabrillo3_qso_append (LOGDB * handle, const qso_t * q)
 	gint rst_len;
 	gchar *q_mode = q[MODE] ? q[MODE] : "SSB";
 	gchar *freq;
+	gchar *res = NULL;
+	struct tm tm_cab;
 
 	/*
 	 * there's no exchange fields in xlog. However, the exchange information
@@ -205,20 +207,23 @@ cabrillo3_qso_append (LOGDB * handle, const qso_t * q)
 	  }
 	}
 
-	/* reshape date */
-	if (strlen (q[DATE]) == 11 && q[DATE][2] == ' ' && q[DATE][6] == ' ')
-		{
-			sprintf (date, "%s-%02d-%c%c", q[DATE] + 7, scan_month (q[DATE] + 3),
-				q[DATE][0], q[DATE][1]);
-		}
+	/* convert "dd <month> yyyy" (month in any language) to dd-mm-yyyy */
+	setlocale (LC_TIME, "");
+	res = strptime (q[DATE], "%d %b %Y", &tm_cab);
+	setlocale (LC_TIME, "C");
+	if (res != NULL)
+	  {
+	    setlocale (LC_TIME, "");
+	    strftime (date, sizeof(date), "%d-%m-%Y", &tm_cab);
+	    setlocale (LC_TIME, "C");
+	  }
 	else
-		{
-			strcpy (date, q[DATE]);
-		}
+	  {
+	    strcpy (date, q[DATE]);
+	  }
 
 	/* translate mode, valid: PH, RY, FM, CW */
-	if (!strcmp (q_mode, "USB") || !strcmp (q_mode, "LSB") ||
-			!strcmp (q_mode, "SSB"))
+	if (!strcmp (q_mode, "USB") || !strcmp (q_mode, "LSB") || !strcmp (q_mode, "SSB"))
 		{
 			mode = "PH";
 		}
@@ -230,6 +235,25 @@ cabrillo3_qso_append (LOGDB * handle, const qso_t * q)
 		{
 			mode = q_mode;
 		}
+
+	// The PSK* modes are not present in the "official"(?) Cabrillo specification
+	// http://www.kkn.net/~trey/cabrillo/qso-template.html
+	// These translations are used in European contests (and maybe others???)
+	// Added at the request of Alex (EW1LN) who showed descriptions of these
+	// modes from 3 European contest sites.
+
+	else if (!strcmp (q_mode, "PSK63"))
+		{
+			mode = "PM";
+		}
+	else if (!strcmp (q_mode, "PSK31"))
+		{
+			mode = "PS";
+		}
+	else if (!strcmp (q_mode, "PSK125"))
+		{
+			mode = "PO";
+		}
 	else
 		mode = "  ";
 
