@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2012 - 2013 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -26,6 +27,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <locale.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 
@@ -125,6 +127,9 @@ labels_qso_append (LOGDB * handle, const qso_t * q)
 	labels_priv_t *priv = (labels_priv_t*)handle->priv;
 	FILE *fp = priv->fp;
 	gint kms, miles, l, result;
+	gchar *res = NULL;
+	struct tm tm_cab;
+	gchar date[16];
 
 	if (priv->prev_call && (strcmp(q[CALL],priv->prev_call) || --priv->groupbycallsign <= 0)) {
 		fprintf (fp, "\n");
@@ -138,7 +143,29 @@ labels_qso_append (LOGDB * handle, const qso_t * q)
 
 	if (preferences.saveastsv2[0] == 1)
 	{
-		if (q[DATE]) fprintf (fp, "%s\t", q[DATE]); else fprintf (fp, "\t");
+	  if (q[DATE])
+	  {
+	    /* convert "dd <month> yyyy" (month in any language) to ISO 8601 YYYY-MM-DD */
+	    setlocale (LC_TIME, "");
+	    res = strptime (q[DATE], "%d %b %Y", &tm_cab);
+	    setlocale (LC_TIME, "C");
+	    if (res != NULL)
+	    {
+	      setlocale (LC_TIME, "");
+	      strftime (date, sizeof(date), "%Y-%m-%d", &tm_cab);
+	      setlocale (LC_TIME, "C");
+	    }
+	    else
+	    {
+	      strcpy (date, q[DATE]);
+	    }
+
+	    fprintf (fp, "%s\t", date);
+	  }
+	  else
+	  {
+	    fprintf (fp, "\t");
+	  }
 	}
 	if (preferences.saveastsv2[1] == 1)
 	{
